#ifdef  DECLSPEC
#undef  DECLSPEC
#endif

#ifdef  DLLEXPORT
#undef  DLLEXPORT
#endif
#ifdef  DLLIMPORT
#undef  DLLIMPORT
#endif

#if defined(WIN32) || defined(__CYGWIN__)
#define DLLEXPORT __declspec(dllexport)
#define DLLIMPORT __declspec(dllimport)
#else
#define DLLEXPORT
#define DLLIMPORT
#endif

#if   defined(__EXPORTSYMBOL__)
#define DECLSPEC DLLEXPORT
#elif defined(__IMPORTSYMBOL__)
#define DECLSPEC DLLIMPORT
#else
#define DECLSPEC
#endif
